from .event import Event
from .publisher import Publisher
from .subscriber import Subscriber


VERSION = (1, 0, 1, 'final')
__version__ = VERSION


def get_version():
    version = '{}.{}'.format(VERSION[0], VERSION[1])
    if VERSION[2]:
        version = '{}.{}'.format(version, VERSION[2])
    if VERSION[3:] == ('alpha', 0):
        version = '{} pre-alpha'.format(version)
    else:
        if VERSION[3] != 'final':
            version = '{} {}'.format(version, VERSION[3])

    return version



from setuptools import setup

from domain_events import get_version

setup(
    name='domain-events',
    version=get_version(),
    license='GPLv3',
    author='Agroptima S.L.',
    author_email='developers@agroptima.com',
    description='A lightweight library with an implementation of Pub-Sub.',
    long_description=open('README.md').read(),
    url='https://github.com/agroptima/domain-events',
    download_url='https://github.com/agroptima/domain-events/releases',
    keywords=['python', 'ddd'],
    packages=['domain_events'],
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Utilities',
    ],
)
